Crate pindakaas

Crate pindakaas 

This crate implements the the internal pindakaas.pindakaas Python module, which provides bindings for the pindakaas Rust crate.

Structs

InvalidEncoder
Raised when the chosen encoder does not support the constraint (e.g. when the PairwiseEncoder encoder for AMO constraints is used to encode a PB constraint).
Unsatisfiable
Raised when the given constraint is found to be Unsatisfiable during encoding.