pub struct IpasirSol<'lib> { /* private fields */ }Expand description
Wrapper around the ipasir_value function that can be used to retrieve the
value of a literal in the current satisfying assignment.